@@ -5,15 +5,12 @@ use Carp qw/croak/;
 use Getopt::Long qw/GetOptionsFromArray/;
 use Pod::Usage;
 use IO::Interactive qw/is_interactive/;
+use Term::ANSIColor qw/colored/;
 
-our $VERSION = '0.041';
+our $VERSION = '0.05';
 
 our $CONFIG_FILE    = '.ygconfig';
 our $DEFAULT_PARSER = 'apache-combined';
-our $DELIMITER_MAP = {
-    space => " ",
-    tab   => "\t",
-};
 our $DIGEST_LENGTH = 6;
 
 use Class::Accessor::Lite (
@@ -81,14 +78,17 @@ sub __out {
 
     my $digest = '';
     if ($self->config->{digest}) {
-        $digest = ": ". substr(Digest::SHA1::sha1_hex(${$line_ref}), 0, $DIGEST_LENGTH);
+        $digest = substr(Digest::SHA1::sha1_hex(${$line_ref}), 0, $DIGEST_LENGTH);
     }
 
     $self->_output_head($self->count, $digest);
     $self->_output_raw($line_ref) if $self->config->{raw};
 
-    if ( defined($self->config->{delimiter}) ) {
-        $self->_output_splited_line($line_ref, $self->config->{delimiter});
+    if ($self->config->{ltsv}) {
+        $self->_output_ltsv_line($line_ref);
+    }
+    elsif ( $self->config->{tab} || $self->config->{space} ) {
+        $self->_output_splited_line($line_ref);
     }
     else {
         $self->_output_parsed_line($line_ref);
@@ -117,13 +117,50 @@ sub _regexp {
 
 sub _output_head {
     my ($self, $count, $digest) = @_;
-    print "******************** $count$digest ********************\n";
+
+    my $colon = $digest ? ': ' : '';
+
+    if ($self->config->{color}) {
+        my $color_hr     = $self->config->{color_hr}     || 'yellow';
+        my $color_count  = $self->config->{color_count}  || 'black';
+        my $color_colon  = $self->config->{color_colon}  || 'cyan';
+        my $color_digest = $self->config->{color_digest} || 'magenta';
+        print colored('******************** ', $color_hr);
+        print colored($count, $color_count);
+        print colored($colon, $color_colon);
+        print colored($digest, $color_digest);
+        print colored(' ********************', $color_hr);
+        print "\n";
+    }
+    else {
+        print "******************** $count$colon$digest ********************\n";
+    }
 }
 
 sub _output_raw {
     print "${$_[1]}\n";
 }
 
+sub _output_ltsv_line {
+    my ($self, $line_ref) = @_;
+
+    my $delimiter = "\t";
+
+    my @cols = split $delimiter, ${$line_ref};
+    my @labels;
+    for my $col (@cols) {
+        my ($label, $value) = split ':', $col;
+        push @labels, $label;
+    }
+    my $lablel_width = _max_label_len(\@labels);
+
+    for my $col (@cols) {
+        my ($label, $value) = split ':', $col;
+        $self->__output_line( sprintf("%${lablel_width}s", $label), $value );
+    }
+    print "\n";
+}
+
 sub _output_parsed_line {
     my ($self, $line_ref) = @_;
 
@@ -134,35 +171,58 @@ sub _output_parsed_line {
     }
     my $i = 0;
     for my $label (@{$self->labels}) {
-        print sprintf($self->label_format, $label, $logs->[$i]);
+        $self->__output_line( sprintf($self->label_format, $label), $logs->[$i] );
         $i++;
     }
     print "\n";
 }
 
 sub _output_splited_line {
-    my ($self, $line_ref, $delimiter) = @_;
+    my ($self, $line_ref) = @_;
 
-    $delimiter = $DELIMITER_MAP->{$delimiter}
-                    ? $DELIMITER_MAP->{$delimiter} : "\t";
+    my $delimiter = $self->config->{space} ? ' ' : "\t";
     my $i = 1;
     my @cols = split $delimiter, ${$line_ref};
-    my $j = length(scalar @cols);
-    for my $col (split $delimiter, ${$line_ref}) {
-        print sprintf("%${j}d: ", $i) if $self->config->{number};
-        print "$col\n";
-        $i++;
+
+    if ($self->config->{number}) {
+        my $j = length(scalar @cols);
+        for my $col (@cols) {
+            $self->__output_line( sprintf("%${j}d", $i), $col );
+            $i++;
+        }
+    }
+    else {
+        for my $col (@cols) {
+            $self->__output_line( '', $col );
+            $i++;
+        }
     }
     print "\n";
 }
 
+sub __output_line {
+    my ($self, $label, $value) = @_;
+
+    if ($self->config->{color}) {
+        my $color_label = $self->config->{color_label} || 'blue';
+        my $color_colon = $self->config->{color_colon} || 'cyan';
+        my $color_value = $self->config->{color_value} || 'green';
+        print colored($label, $color_label);
+        print colored(': ', $color_colon) if $label;
+        print colored("$value\n", $color_value);
+    }
+    else {
+        print "$label: " if $label;
+        print "$value\n";
+    }
+}
+
 sub pre {
     my ($self, $argv) = @_;
 
     my $config = $self->_set_config;
     $self->_merge_opt($config, $argv);
     $self->config($config);
-
     $self->parse_class(
         $self->_load_parser($config->{parser} || $DEFAULT_PARSER)
     );
@@ -172,7 +232,7 @@ sub pre {
         $self->labels( &{ $self->parse_class. '::labels' }() );
     }
     $self->label_format(
-        '%'. _max_label_len($self->labels). "s: %s\n"
+        '%'. _max_label_len($self->labels). 's'
     );
 
     if ($self->config->{digest}) {
@@ -224,7 +284,8 @@ sub _merge_opt {
         $argv,
         'f|file=s@'      => \$config->{file},
         'p|parser=s'     => \$config->{parser},
-        'd|delimiter:s'  => \$config->{delimiter},
+        'tab'            => \$config->{tab},
+        'space'          => \$config->{space},
         'n|number!'      => \$config->{number},
         'm|match=s'      => \$config->{match},
         're|regexp=s'    => \$config->{regexp},
@@ -232,6 +293,14 @@ sub _merge_opt {
         'r|raw'          => \$config->{raw},
         't|through'      => \$config->{through},
         'digest!'        => \$config->{digest},
+        'ltsv'           => \$config->{ltsv},
+        'c|color!'       => \$config->{color},
+        'color-label=s'  => \$config->{color_label},
+        'color-colon=s'  => \$config->{color_colon},
+        'color-value=s'  => \$config->{color_value},
+        'color-hr=s'     => \$config->{color_hr},
+        'color-count=s'  => \$config->{color_count},
+        'color-digest=s' => \$config->{color_digest},
         'h|help'         => sub {
             pod2usage(1);
         },
@@ -286,6 +355,8 @@ App::YG - log line filter, like \G of MySQL
     my $yg = App::YG->new;
     $yg->run(@ARGV);
 
+See command L<yg>.
+
 
 =head1 METHOD
 
